@@ -10,7 +10,7 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-"""This module has customizations to unify paging paramters.
+"""This module has customizations to unify paging parameters.
 
 For any operation that can be paginated, we will:
 
@@ -255,6 +255,7 @@ class PageArgument(BaseCLIArgument):
     type_map = {
         'string': str,
         'integer': int,
+        'long': int,
     }
 
     def __init__(self, name, documentation, parse_type, serialized_name):
